caption {
	font-family: Helvetica;
	font-size: 18px;
	font-weight: bold;
	color: #003161;
}
th {
	font-family: Helvetica;
	font-size: 14px;
	font-weight: bold;
	color: #003161;
	padding: 0;
}
a:link {
	color: #003161;
	text-decoration: none;
}
a:active {
	color: #003161;
	text-decoration: none;
}
a:visited {
	color: #003161;
	text-decoration: none;
}
a:hover {
	color: #c0c0c0;
	text-decoration: underline;
}
td {
	font-family: Helvetica;
	font-size: 12px;
	font-weight: normal;
	padding: 0;
}
a.navbutton {
	display: block;
	width: 52px;
	height: 50px;
	background-repeat: no-repeat;
}
a.nav-transfer {
	background-image: url(images/transf_0.png);
}
a.nav-transfer:hover {
	background-image: url(images/transf_1.png);
}
a.nav-shared {
	background-image: url(images/shared_0.png);
}
a.nav-shared:hover {
	background-image: url(images/shared_1.png);
}
a.nav-search {
	background-image: url(images/search_0.png);
}
a.nav-search:hover {
	background-image: url(images/search_1.png);
}
a.nav-servers {
	background-image: url(images/edkserv_0.png);
}
a.nav-servers:hover {
	background-image: url(images/edkserv_1.png);
}
a.nav-kad {
	background-image: url(images/sheserv_0.png);
}
a.nav-kad:hover {
	background-image: url(images/sheserv_1.png);
}
a.nav-stats {
	background-image: url(images/stats_0.png);
}
a.nav-stats:hover {
	background-image: url(images/stats_1.png);
}
.texte {
	font-family: Helvetica;
	font-size: 12px;
	font-weight: normal;
	overflow: hidden;
	white-space: nowrap;
	text-overflow: ellipsis;
	word-break: break-all;
	word-wrap: break-word;
}
.texte-full-name {
	max-width: 0;
	width: 45%;
}
.texte-full-name-upload {
	width: 55%;
}
.texte-full-name-search {
	width: 75%;
}
label {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 12px;
	font-weight: bold;
}
input, button {
	border: 1px solid #003161;
	background-color: white;
	font-family: Helvetica, Arial, sans-serif;
	font-size: 12px;
	color: #003161;
}
select, option {
	border: 1px solid #003161;
	background-color: white;
	font-family: Helvetica, Arial, sans-serif;
	font-size: 12px;
	color: #003161;
}
textarea {
	border: 1px solid #003161;
	background-color: #90B6DB;
	font-family: Helvetica, Arial, sans-serif;
	font-size: 12px;
	color: white;
}
html,
body.main {
	height: 100%;
}
body.main {
	margin: 0;
	background-image: url(images/fond.gif);
}
img {
	border: 0;
}
.al-left {
	text-align: left;
}
.al-center {
	text-align: center;
}
.al-right {
	text-align: right;
}
.va-top {
	vertical-align: top;
}
.va-middle {
	vertical-align: middle;
}
.va-bottom {
	vertical-align: bottom;
}
.center-table {
	margin-left: auto;
	margin-right: auto;
}
table.page {
	width: 100%;
	height: 100%;
}
table.page > tbody > tr:first-child {
	vertical-align: top;
}
table.page > tbody > tr:nth-child(2) {
	vertical-align: top;
}
table.page > tbody > tr:last-child {
	vertical-align: bottom;
}
table.page > tbody > tr:last-child > td {
	height: 25px;
}
td.logo-cell {
	width: 143px;
	height: 64px;
}
td.logo-cell img {
	display: block;
}
td.navbar-cell {
	width: 100%;
	height: 64px;
	background-image: url(images/fond_haut.png);
}
td.navbar-cell img {
	display: block;
}
table.navbar-table {
	margin-left: auto;
}
table.navbar-table > tbody > tr > td:nth-last-child(1),
table.navbar-table > tbody > tr > td:nth-last-child(3) {
	width: 10px;
}
table.navbar-table > tbody > tr > td:nth-last-child(2) {
	width: 190px;
	text-align: right;
	font-family: Helvetica;
	font-size: 12px;
	font-weight: bold;
	color: white;
}
table.kadnewnode {
	margin-left: auto;
	margin-right: auto;
	border-spacing: 6px;
}
table.prefs-grid {
	margin-left: auto;
	margin-right: auto;
	border-spacing: 6px;
}
table.prefs-grid > tbody > tr:last-child {
	text-align: center;
}
table.prefs-grid > tbody > tr:not(:last-child) {
	vertical-align: top;
}
table.prefs-grid > tbody > tr > td:nth-child(2) {
	width: 50%;
}
table.prefs-pane {
	width: 350px;
	margin-left: auto;
	margin-right: auto;
}
table.prefs-pane > tbody > tr > td:first-child {
	width: 22px;
}
table.prefs-pane > tbody > tr > td:last-child {
	width: 63px;
}
table.prefs-pane > tbody > tr:not(:first-child) > td {
	height: 25px;
}
table.footer-bar {
	width: 100%;
	height: 40px;
	background-color: #FFFFFF;
}
table.footer-bar > tbody > tr {
	text-align: center;
	vertical-align: middle;
}
table.footer-bar > tbody > tr > td {
	width: 50%;
	background-color: #FFFFFF;
}
table.footer-bar iframe {
	width: 100%;
	height: 35px;
	display: block;
	border: 0;
}
table.tab {
	width: 100%;
}
table.tab > tbody > tr:first-child > td > img,
table.tab > tbody > tr:last-child > td > img {
	display: block;
}
table.tab > tbody > tr > td:first-child,
table.tab > tbody > tr > td:last-child {
	width: 24px;
}
table.tab > tbody > tr:first-child > td:nth-child(2) {
	background-image: url(images/tab_top.png);
}
table.tab > tbody > tr:nth-child(2) > td:first-child {
	background-image: url(images/tab_left.png);
}
table.tab > tbody > tr:nth-child(2) > td:nth-child(2) {
	background-color: #FFFFFF;
}
table.tab > tbody > tr:nth-child(2) > td:last-child {
	background-image: url(images/tab_right.png);
}
table.tab > tbody > tr:last-child > td:nth-child(2) {
	background-image: url(images/tab_bottom.png);
}
.bg-white {
	background-color: #FFFFFF;
}
.bg-black {
	background-color: #000000;
}
td.sep-dark {
	height: 1px;
	background-color: #000000;
}
td.sep-light {
	height: 1px;
	background-color: #c0c0c0;
}
.h10 {
	height: 10px;
}
.h15 {
	height: 15px;
}
.h19 {
	height: 19px;
}
.h20 {
	height: 20px;
}
.h22 {
	height: 22px;
}
.h30 {
	height: 30px;
}
.h180 {
	height: 180px;
}
.h200 {
	height: 200px;
}
.h90p {
	height: 90%;
}
.h100p {
	height: 100%;
}
.w366 {
	width: 366px;
}
.w500 {
	width: 500px;
}
.w3p {
	width: 3%;
}
.w7p {
	width: 7%;
}
.w19p {
	width: 19%;
}
.w22p {
	width: 22%;
}
.w42p {
	width: 42%;
}
.w50p {
	width: 50%;
}
.w65p {
	width: 65%;
}
.w70p {
	width: 70%;
}
.w100p {
	width: 100%;
}
table {
	border-spacing: 0;
}
table.spacing1 {
	border-spacing: 1px;
}
table.pad4 > tbody > tr > td {
	padding: 4px;
}
iframe.noborder {
	border: 0;
}
iframe[name="logframe"], iframe[name="srvframe"] {
	border: 1px solid #003161;
}
select[name="status"] {
	margin-right: 6px;
}
body.frame {
	overflow: hidden;
	background-color: #FFFFFF;
}
th.login-banner {
	height: 180px;
	text-align: right;
	vertical-align: middle;
	background-image: url(images/loginfond_haut.png);
	color: #000000;
}
th.login-logo > img {
	display: block;
}
.login-error {
	display: inline-block;
	margin-top: 6px;
	padding: 3px 10px;
	background-color: #c00000;
	color: white;
	font-weight: bold;
}
